import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/hoverBuilder/hoverBuilder.dart';

import '../constants.dart';

class DefaultCard extends StatefulWidget {
  final Color? backgroundColor;
  final Widget child;
  final Color? shadowColor;
  final double? elevation;
  final Function? onTap;
  final bool? lightUpOnHover;
  final bool? lightUpOnTap;
  final bool? addBorder;
  final bool? raiseOnHover;

  const DefaultCard({
    Key? key,
    this.backgroundColor,
    required this.child,
    this.shadowColor,
    this.elevation,
    this.lightUpOnHover,
    this.lightUpOnTap,
    this.onTap,
    this.addBorder,
    this.raiseOnHover,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultCardState();
  }
}

class _DefaultCardState extends State<DefaultCard> {
  Color? shadowColor;
  double? elevation;
  bool? hasFocus;

  @override
  void initState() {
    shadowColor = widget.shadowColor ?? defaultShadow;
    elevation = widget.elevation ?? defaultElevation;
    hasFocus = false;
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  setActive() {
    setState(() {
      shadowColor = softcorpPrimaryColor;
      elevation = 12.0;
    });
  }

  setDefault() {
    setState(() {
      shadowColor = widget.shadowColor ?? defaultShadow;
      elevation = widget.elevation ?? defaultElevation;
    });
  }

  @override
  Widget build(BuildContext context) {
    Widget defaultCard = Card(
      elevation: elevation,
      color: widget.backgroundColor,
      semanticContainer: true,
      clipBehavior: Clip.antiAliasWithSaveLayer,
      shadowColor: shadowColor,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(defaultCornerRadius),
        side: (widget.elevation == 0 && widget.addBorder == true)
            ? const BorderSide(
                color: borderColor,
                width: 1.2,
              )
            : BorderSide.none,
      ),
      margin: const EdgeInsets.all(10),
      child: widget.child,
    );
    Widget onTapWidget = defaultCard;
    if (widget.onTap != null) {
      Widget raiseOnHoverWidget = defaultCard;
      if (widget.raiseOnHover == true) {
        raiseOnHoverWidget = RaiseOnHover(builder: (isHovered) {
          return defaultCard;
        });
      }
      onTapWidget = GestureDetector(
        onTap: () => widget.onTap!(),
        child: raiseOnHoverWidget,
      );
      print("get down here 1");
    }
    Widget lightUpOnHover = onTapWidget;
    if (widget.lightUpOnHover == true) {
      lightUpOnHover = MouseRegion(
        onEnter: (_) {
          if (hasFocus == false) {
            setActive();
          }
        },
        onExit: (_) {
          if (hasFocus == false) {
            setDefault();
          }
        },
        cursor: SystemMouseCursors.click,
        child: onTapWidget,
      );
      print("get down here 2");
    }
    Widget lightUpOnTap = lightUpOnHover;
    if (widget.lightUpOnTap == true) {
      lightUpOnTap = Focus(
        onFocusChange: (focus) {
          if (focus == true) {
            setActive();
          } else {
            setDefault();
          }
          setState(() {
            hasFocus = focus;
          });
        },
        child: lightUpOnHover,
      );
      print("get down here 3");
    }
    return lightUpOnTap;
  }
}
