import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';

import '../constants.dart';

class DefaultFormField extends StatelessWidget {
  final TextEditingController textEditingController;
  final TextInputType textInputType;
  final String hint;
  final String label;
  final String? Function(String?)? validator;
  final BoxConstraints? constraints;
  final int? numberOfLines;
  final bool? disabled;
  final bool? addDefaultBorder;
  final Color? labelColor;
  final IconData? prefixIcon;
  final bool? obscureText;

  const DefaultFormField({
    Key? key,
    required this.textEditingController,
    required this.textInputType,
    required this.hint,
    required this.label,
    this.validator,
    this.addDefaultBorder,
    this.constraints,
    this.numberOfLines,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
    this.obscureText,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return DefaultCard(
      shadowColor: defaultLightShadow,
      raiseOnHover: false,
      lightUpOnHover: false,
      lightUpOnTap: true,
      child: TextFormField(
        enabled: disabled == null ? true : (disabled),
        controller: textEditingController,
        obscureText: obscureText ?? false,
        keyboardType: textInputType,
        style: const TextStyle(color: Colors.black),
        decoration: InputDecoration(
          hintText: hint,
          hoverColor: Colors.transparent,
          disabledBorder: const OutlineInputBorder(
            borderSide: BorderSide.none,
            borderRadius: BorderRadius.all(
              Radius.circular(defaultCornerRadius),
            ),
          ),
          enabledBorder: const OutlineInputBorder(
            borderSide: BorderSide.none,
            borderRadius: BorderRadius.all(
              Radius.circular(defaultCornerRadius),
            ),
          ),
          focusedBorder: const OutlineInputBorder(
            borderSide: BorderSide.none,
            borderRadius: BorderRadius.all(
              Radius.circular(defaultCornerRadius),
            ),
          ),
          errorBorder: const OutlineInputBorder(
            borderSide: BorderSide.none,
            borderRadius: BorderRadius.all(
              Radius.circular(defaultCornerRadius),
            ),
          ),
          focusedErrorBorder: const OutlineInputBorder(
            borderSide: BorderSide.none,
            borderRadius: BorderRadius.all(
              Radius.circular(defaultCornerRadius),
            ),
          ),
          hintStyle: const TextStyle(fontSize: 16, color: Colors.grey),
          filled: true,
          prefixIcon: prefixIcon != null
              ? Icon(
                  prefixIcon,
                  size: 15,
                  color: defaultSubTitleColor,
                )
              : null,
          contentPadding: const EdgeInsets.all(16),
          fillColor: disabled == true ? Colors.grey[200] : Colors.white,
        ),
        validator: validator,
        maxLines: obscureText == true ? 1 : numberOfLines,
      ),
    );
  }
}
